<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => '.',
    'None' => 'Ingen',
    'Edit' => 'Rediger',
    'Remove' => 'Fjern',
    'Yes' => 'Ja',
    'No' => 'Nei',
    'cancel' => 'avbryt',
    'or' => 'eller',
    'Yellow' => 'Gul',
    'Blue' => 'Blå',
    'Green' => 'Grønn',
    'Purple' => 'Lilla',
    'Red' => 'Rød',
    'Orange' => 'Orange',
    'Grey' => 'Grå',
    'Brown' => 'Brun',
    'Deep Orange' => 'Mørk orange',
    'Dark Grey' => 'Mørk grå',
    'Pink' => 'Rosa',
    'Teal' => 'Sjøgrønn',
    'Cyan' => 'Cyan',
    'Lime' => 'Lime',
    'Light Green' => 'Lys grønn',
    'Amber' => 'Ravgul',
    'Save' => 'Lagre',
    'Login' => 'Logg inn',
    'Official website:' => 'Offisielt nettsted:',
    'Unassigned' => 'Ikke tildelt',
    'View this task' => 'Se denne oppgaven',
    'Remove user' => 'Fjern bruker',
    'Do you really want to remove this user: "%s"?' => 'Er du sikker på at du vil fjerne brukeren: "%s"?',
    'All users' => 'Alle brukere',
    'Username' => 'Brukernavn',
    'Password' => 'Passord',
    'Administrator' => 'Administrator',
    'Sign in' => 'Logg inn',
    'Users' => 'Brukere',
    'Forbidden' => 'Ikke tillatt',
    'Access Forbidden' => 'Adgang ikke tillatt',
    'Edit user' => 'Rediger bruker',
    'Logout' => 'Logg ut',
    'Bad username or password' => 'Feil brukernavn eller passord',
    'Edit project' => 'Endre prosjekt',
    'Name' => 'Navn',
    'Projects' => 'Prosjekter',
    'No project' => 'Ingen prosjekter',
    'Project' => 'Prosjekt',
    'Status' => 'Status',
    'Tasks' => 'Oppgaver',
    'Board' => 'Tavle',
    'Actions' => 'Handlinger',
    'Inactive' => 'Inaktiv',
    'Active' => 'Aktiv',
    'Unable to update this board.' => 'Ikke mulig å oppdatere tavlesiden',
    'Disable' => 'Slå av',
    'Enable' => 'Slå på',
    'New project' => 'Nytt prosjekt',
    'Do you really want to remove this project: "%s"?' => 'Er du sikker på at du vil du slette dette prosjektet: "%s"?',
    'Remove project' => 'Slett prosjekt',
    'Edit the board for "%s"' => 'Endre tavlesiden for "%s"',
    'Add a new column' => 'Legg til ny kolonne',
    'Title' => 'Tittel',
    'Assigned to %s' => 'Tildelt: %s',
    'Remove a column' => 'Fjern en kolonne',
    'Unable to remove this column.' => 'Kan ikke fjerne kolonnen',
    'Do you really want to remove this column: "%s"?' => 'Er du sikker på at du vil fjerne denne kolonnen: "%s"?',
    'Settings' => 'Innstillinger',
    'Application settings' => 'Applikasjonsinnstillinger',
    'Language' => 'Språk',
    'Webhook token:' => 'Webhook token:',
    'API token:' => 'API token:',
    'Database size:' => 'Databasestørrelse:',
    'Download the database' => 'Last ned databasen',
    'Optimize the database' => 'Optimaliser databasen',
    '(VACUUM command)' => '(VACUUM kommando)',
    '(Gzip compressed Sqlite file)' => '(Gzip-komprimert Sqlite fil)',
    'Close a task' => 'Lukk oppgave',
    'Column' => 'Kolonne',
    'Color' => 'Farge',
    'Assignee' => 'Tildelt',
    'Create another task' => 'Opprett en ny oppgave etter denne',
    'New task' => 'Ny oppgave',
    'Open a task' => 'Åpne oppgave',
    'Do you really want to open this task: "%s"?' => 'Er du sikker på at du vil åpne denne oppgaven: "%s"?',
    'Back to the board' => 'Tilbake til tavlesiden',
    'There is nobody assigned' => 'Mangler tildeling',
    'Column on the board:' => 'Kolonne:',
    'Close this task' => 'Lukk oppgave',
    'Open this task' => 'Åpne oppgave',
    'There is no description.' => 'Ingen beskrivelse.',
    'Add a new task' => 'Lag ny oppgave',
    'The username is required' => 'Brukernavn er påkrevd',
    'The maximum length is %d characters' => 'Den maksimale lengden er %d tegn',
    'The minimum length is %d characters' => 'Den minimale lengden er %d tegn',
    'The password is required' => 'Passord påkrevet',
    'This value must be an integer' => 'Verdien må være et heltall',
    'The username must be unique' => 'Brukernavnet må være unikt',
    'The user id is required' => 'Bruker-id påkrevet',
    'Passwords don\'t match' => 'Passordene stemmer ikke overens',
    'The confirmation is required' => 'Bekreftelse påkrevet',
    'The project is required' => 'Prosjekt påkrevet',
    'The id is required' => 'ID påkrevet',
    'The project id is required' => 'Prosjekt-id påkrevet',
    'The project name is required' => 'Prosjektnavn påkrevet',
    'The title is required' => 'Tittel påkrevet',
    'Settings saved successfully.' => 'Innstillinger lagret.',
    'Unable to save your settings.' => 'Feil ved lagring av innstillinger.',
    'Database optimization done.' => 'Databaseoptimalisering er fullført.',
    'Your project has been created successfully.' => 'Prosjektet er opprettet.',
    'Unable to create your project.' => 'Prosjektet kunne ikke opprettes',
    'Project updated successfully.' => 'Prosjektet er oppdatert.',
    'Unable to update this project.' => 'Prosjektet kunne ikke oppdateres.',
    'Unable to remove this project.' => 'Prosjektet kunne ikke slettes.',
    'Project removed successfully.' => 'Prosjektet er slettet.',
    'Project activated successfully.' => 'Prosjektet er aktivert.',
    'Unable to activate this project.' => 'Prosjektet kunne ikke aktiveres.',
    'Project disabled successfully.' => 'Prosjektet er deaktiveret.',
    'Unable to disable this project.' => 'Prosjektet kunne ikke deaktiveres.',
    'Unable to open this task.' => 'Oppgaven kunne ikke åpnes.',
    'Task opened successfully.' => 'Oppgaven er åpnet.',
    'Unable to close this task.' => 'Oppgaven kunne ikke åpnes.',
    'Task closed successfully.' => 'Oppgaven er lukket.',
    'Unable to update your task.' => 'Oppgaven kunne ikke oppdateres.',
    'Task updated successfully.' => 'Oppgaven er oppdatert.',
    'Unable to create your task.' => 'Oppgave kunne ikke opprettes.',
    'Task created successfully.' => 'Oppgaven er opprettet.',
    'User created successfully.' => 'Brukeren er opprettet.',
    'Unable to create your user.' => 'Brukeren kunne ikke opprettes.',
    'User updated successfully.' => 'Brukeren er oppdatert',
    'User removed successfully.' => 'Brukeren er fjernet.',
    'Unable to remove this user.' => 'Brukeren kunne ikke slettes.',
    'Board updated successfully.' => 'Hovedsiden er oppdatert.',
    'Ready' => 'Klar',
    'Backlog' => 'Backlog',
    'Work in progress' => 'Under arbeid',
    'Done' => 'Utført',
    'Application version:' => 'Versjon:',
    'Id' => 'ID',
    'Public link' => 'Offentligt lenke',
    'Timezone' => 'Tidssone',
    'Sorry, I didn\'t find this information in my database!' => 'Denne informasjonen kunne ikke finnes i databasen!',
    'Page not found' => 'Siden er ikke funnet',
    'Complexity' => 'Kompleksitet',
    'Task limit' => 'Oppgavebegrensning',
    'Task count' => 'Antall oppgaver',
    'User' => 'Bruker',
    'Comments' => 'Kommentarer',
    'Comment is required' => 'Kommentar må legges inn',
    'Comment added successfully.' => 'Kommentaren er lagt til.',
    'Unable to create your comment.' => 'Din kommentar kunne ikke opprettes.',
    'Due Date' => 'Frist',
    'Invalid date' => 'Ugyldig dato',
    'Automatic actions' => 'Automatiske handlinger',
    'Your automatic action has been created successfully.' => 'Din automatiske handling er opprettet.',
    'Unable to create your automatic action.' => 'Din automatiske handling kunne ikke opprettes.',
    'Remove an action' => 'Fjern en handling',
    'Unable to remove this action.' => 'Handlingen kunne ikke fjernes.',
    'Action removed successfully.' => 'Handlingen er fjernet.',
    'Automatic actions for the project "%s"' => 'Automatiske handlinger for prosjektet "%s"',
    'Add an action' => 'Legg til en handling',
    'Event name' => 'Hendelsehet',
    'Action' => 'Handling',
    'Event' => 'Hendelse',
    'When the selected event occurs execute the corresponding action.' => 'Når den valgte hendelsen oppstår, utfør tilsvarende handling.',
    'Next step' => 'Neste',
    'Define action parameters' => 'Definer handlingsparametre',
    'Do you really want to remove this action: "%s"?' => 'Vil du slette denne handlingen: "%s"?',
    'Remove an automatic action' => 'Fjern en automatisk handling',
    'Assign the task to a specific user' => 'Tildel oppgaven til en bestemt bruker',
    'Assign the task to the person who does the action' => 'Tildel oppgaven til den person, som utfører  handlingen',
    'Duplicate the task to another project' => 'Kopier oppgaven til et annet prosjekt',
    'Move a task to another column' => 'Flytt oppgaven til en annen kolonne',
    'Task modification' => 'Oppgaveendring',
    'Task creation' => 'Oppgaveoprettelse',
    'Closing a task' => 'Lukke en oppgave',
    'Assign a color to a specific user' => 'Tildel en farge til en bestemt bruker',
    'Position' => 'Posisjon',
    'Duplicate to project' => 'Kopier til et annet prosjekt',
    'Duplicate' => 'Kopier',
    'Link' => 'Link',
    'Comment updated successfully.' => 'Kommentar oppdatert.',
    'Unable to update your comment.' => 'Din kommentar kunne ikke oppdateres.',
    'Remove a comment' => 'Fjern en kommentar',
    'Comment removed successfully.' => 'Kommentaren ble fjernet.',
    'Unable to remove this comment.' => 'Kommentaren kunne ikke fjernes.',
    'Do you really want to remove this comment?' => 'Vil du fjerne denne kommentaren?',
    'Current password for the user "%s"' => 'Aktivt passord for brukeren "%s"',
    'The current password is required' => 'Passord er påkrevet',
    'Wrong password' => 'Feil passord',
    'Unknown' => 'Ukjent',
    'Last logins' => 'Siste innlogging',
    'Login date' => 'Login dato',
    'Authentication method' => 'Godkjenningsmetode',
    'IP address' => 'IP Adresse',
    'User agent' => 'User Agent',
    'Persistent connections' => 'Nettforbindelser',
    'No session.' => 'Ingen sesjoner.',
    'Expiration date' => 'Utløpsdato',
    'Remember Me' => 'Husk meg',
    'Creation date' => 'Opprettelsesdato',
    'Everybody' => 'Alle',
    'Open' => 'Åpen',
    'Closed' => 'Lukket',
    'Search' => 'Søk',
    'Nothing found.' => 'Intet funnet.',
    'Due date' => 'Tidsfrist',
    'Description' => 'Beskrivelse',
    '%d comments' => '%d kommentarer',
    '%d comment' => '%d kommentar',
    'Email address invalid' => 'Ugyldig epost',
    'Your external account is not linked anymore to your profile.' => 'Din eksterne konto er ikke lenger lenket til profilen din',
    'Unable to unlink your external account.' => 'Kan ikke fjerne lenken til din eksterne konto',
    'External authentication failed' => 'Ekstern autentisering feilet',
    'Your external account is linked to your profile successfully.' => 'Den eksterne konto er lenket til profilen din',
    'Email' => 'E-post',
    'Task removed successfully.' => 'Oppgaven er fjernet.',
    'Unable to remove this task.' => 'Oppgaven kunne ikke fjernes.',
    'Remove a task' => 'Fjern en oppgave',
    'Do you really want to remove this task: "%s"?' => 'Vil du fjerne denne oppgaven: "%s"?',
    'Assign automatically a color based on a category' => 'Tildel automatisk en farge baseret for en kategori',
    'Assign automatically a category based on a color' => 'Tildel automatisk en kategori basert på en farve',
    'Task creation or modification' => 'Oppgaveopprettelse eller endring',
    'Category' => 'Kategori',
    'Category:' => 'Kategori:',
    'Categories' => 'Kategorier',
    'Your category has been created successfully.' => 'Kategorien er opprettet.',
    'This category has been updated successfully.' => 'Kategorien er oppdatert.',
    'Unable to update this category.' => 'Kategorien kunne ikke oppdateres.',
    'Remove a category' => 'Fjern en kategori',
    'Category removed successfully.' => 'Kategorien er fjernet.',
    'Unable to remove this category.' => 'Kategorien kunne ikke fjernes.',
    'Category modification for the project "%s"' => 'Endring av kategori for prosjektet "%s"',
    'Category Name' => 'Kategorinavn',
    'Add a new category' => 'Legg til  ny kategori',
    'Do you really want to remove this category: "%s"?' => 'Vil du fjerne kategorien: "%s"?',
    'All categories' => 'Alle kategorier',
    'No category' => 'Ingen kategori',
    'The name is required' => 'Navnet er påkrevet',
    'Remove a file' => 'Fjern en fil',
    'Unable to remove this file.' => 'Filen kunne ikke fjernes.',
    'File removed successfully.' => 'Filen er fjernet.',
    'Attach a document' => 'Legg til  et dokument',
    'Do you really want to remove this file: "%s"?' => 'Vil du fjerne filen: "%s"?',
    'Attachments' => 'Vedlegg',
    'Edit the task' => 'Rediger oppgaven',
    'Add a comment' => 'Legg til en kommentar',
    'Edit a comment' => 'Rediger en kommentar',
    'Summary' => 'Sammendrag',
    'Time tracking' => 'Tidsregistrering',
    'Estimate:' => 'Estimat:',
    'Spent:' => 'Brukt:',
    'Do you really want to remove this sub-task?' => 'Vil du fjerne denne deloppgaven?',
    'Remaining:' => 'Gjenværende:',
    'hours' => 'timer',
    'estimated' => 'estimat',
    'Sub-Tasks' => 'Deloppgave',
    'Add a sub-task' => 'Legg til en deloppgave',
    'Original estimate' => 'Estimert tidsbruk',
    'Create another sub-task' => 'Legg til en ny deloppgave',
    'Time spent' => 'Tidsforbruk',
    'Edit a sub-task' => 'Rediger en deloppgave',
    'Remove a sub-task' => 'Fjern en deloppgave',
    'The time must be a numeric value' => 'Tiden skal være en nummerisk erdi',
    'Todo' => 'Gjøremål',
    'In progress' => 'Under arbeid',
    'Sub-task removed successfully.' => 'Deloppgaven er fjernet.',
    'Unable to remove this sub-task.' => 'Deloppgaven kunne ikke fjernes.',
    'Sub-task updated successfully.' => 'Deloppgaven er opdateret.',
    'Unable to update your sub-task.' => 'Deloppgaven kunne ikke opdateres.',
    'Unable to create your sub-task.' => 'Deloppgaven kunne ikke oprettes.',
    'Maximum size: ' => 'Maksimum størrelse: ',
    'Display another project' => 'Vis annet prosjekt...',
    'Created by %s' => 'Opprettet av %s',
    'Tasks Export' => 'Oppgave eksport',
    'Start Date' => 'Startdato',
    'Execute' => 'KKjør',
    'Task Id' => 'Oppgave ID',
    'Creator' => 'Laget av',
    'Modification date' => 'Endringsdato',
    'Completion date' => 'Ferdigstillingsdato',
    'Clone' => 'Kopier',
    'Project cloned successfully.' => 'Prosjektet er kopiert.',
    'Unable to clone this project.' => 'Prosjektet kunne ikke kopieres',
    'Enable email notifications' => 'Aktiver epostvarslinger',
    'Task position:' => 'Posisjon:',
    'The task #%d has been opened.' => 'Oppgaven #%d er åpnet.',
    'The task #%d has been closed.' => 'Oppgaven #%d er lukket.',
    'Sub-task updated' => 'Deloppgaven er oppdatert',
    'Title:' => 'Tittel:',
    'Status:' => 'Status:',
    'Assignee:' => 'Ansvarlig:',
    'Time tracking:' => 'Tidsmåling:',
    'New sub-task' => 'Ny deloppgave',
    'New attachment added "%s"' => 'Nytt vedlegg er lagt tilet "%s"',
    'New comment posted by %s' => 'Ny kommentar fra %s',
    'New comment' => 'Ny kommentar',
    'Comment updated' => 'Kommentar oppdatert',
    'New subtask' => 'Ny deloppgave',
    'I only want to receive notifications for these projects:' => 'Jeg vil kun ha varslinger for disse prosjekter:',
    'view the task on Kanboard' => 'se oppgaven',
    'Public access' => 'Offentlig tilgang',
    'Disable public access' => 'Deaktiver offentlig tilgang',
    'Enable public access' => 'Aktiver offentlig tilgang',
    'Public access disabled' => 'Offentlig tilgang er deaktivert',
    'Move the task to another project' => 'Flytt oppgaven til et annet prosjekt',
    'Move to project' => 'Flytt til et annet prosjekt',
    'Do you really want to duplicate this task?' => 'Vil du kopiere denne oppgaven?',
    'Duplicate a task' => 'Kopier en oppgave',
    'External accounts' => 'Eksterne kontoer',
    'Account type' => 'Kontotype',
    'Local' => 'Lokal',
    'Remote' => 'Fjernstyrt',
    'Enabled' => 'Aktiv',
    'Disabled' => 'Deaktivert',
    'Login:' => 'Brukernavn',
    'Full Name:' => 'Navn:',
    'Email:' => 'Epost:',
    'Notifications:' => 'Varslinger:',
    'Notifications' => 'Varslinger',
    'Account type:' => 'Konto type:',
    'Edit profile' => 'Rediger profil',
    'Change password' => 'Endre passord',
    'Password modification' => 'Passordendring',
    'External authentications' => 'Ekstern godkjenning',
    'Never connected.' => 'Aldri innlogget.',
    'No external authentication enabled.' => 'Ingen eksterne godkjenninger aktiveret.',
    'Password modified successfully.' => 'Passord er endret.',
    'Unable to change the password.' => 'Passordet kuenne ikke endres.',
    'Change category' => 'Endre kategori',
    '%s updated the task %s' => '%s oppdaterte oppgaven %s',
    '%s opened the task %s' => '%s åpnet oppgaven %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s flyttet oppgaven %s til posisjon #%d i kolonne "%s"',
    '%s moved the task %s to the column "%s"' => '%s flyttet oppgaven %s til kolonnen "%s"',
    '%s created the task %s' => '%s opprettet oppgaven %s',
    '%s closed the task %s' => '%s lukket oppgaven %s',
    '%s created a subtask for the task %s' => '%s opprettet en deloppgave for oppgaven %s',
    '%s updated a subtask for the task %s' => '%s oppdaterte en deloppgave for oppgaven %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Tildelt til %s med et estimat på %s/%sh',
    'Not assigned, estimate of %sh' => 'Ikke tildelt, estimert til %sh',
    '%s updated a comment on the task %s' => '%s oppdaterte en kommentar til oppgaven %s',
    '%s commented the task %s' => '%s har kommentert oppgaven %s',
    '%s\'s activity' => 'Aktiviteter: %s',
    'RSS feed' => 'RSS feed',
    '%s updated a comment on the task #%d' => '%s oppdaterte en kommentar til oppgaven #%d',
    '%s commented on the task #%d' => '%s kommenterte oppgaven #%d',
    '%s updated a subtask for the task #%d' => '%s oppdaterte en deloppgave til oppgaven #%d',
    '%s created a subtask for the task #%d' => '%s opprettet en deloppgave til oppgaven #%d',
    '%s updated the task #%d' => '%s oppdaterte oppgaven #%d',
    '%s created the task #%d' => '%s opprettet oppgaven #%d',
    '%s closed the task #%d' => '%s lukket oppgaven #%d',
    '%s opened the task #%d' => '%s åpnet oppgaven #%d',
    'Activity' => 'Aktivitetslogg',
    'Default values are "%s"' => 'Standardverdier  er "%s"',
    'Default columns for new projects (Comma-separated)' => 'Standard kolonne for nye prosjekter (kommaseparert)',
    'Task assignee change' => 'Endring av oppgaveansvarlig',
    '%s changed the assignee of the task #%d to %s' => '%s endre ansvarlig for oppgaven #%d til %s',
    '%s changed the assignee of the task %s to %s' => '%s endret ansvarlig for oppgaven %s til %s',
    'New password for the user "%s"' => 'Nytt passord for brukeren "%s"',
    'Choose an event' => 'Velg en hendelse',
    'Create a task from an external provider' => 'Oppret en oppgave fra en ekstern tilbyder',
    'Change the assignee based on an external username' => 'Endre ansvarlige baseret på et eksternt brukernavn',
    'Change the category based on an external label' => 'Endre kategorien basert på en ekstern etikett',
    'Reference' => 'Referanse',
    'Label' => 'Etikett',
    'Database' => 'Database',
    'About' => 'Om',
    'Database driver:' => 'Databasedriver:',
    'Board settings' => 'Tavlesiden',
    'Webhook settings' => 'Webhook innstillinger',
    'Reset token' => 'Resette token',
    'API endpoint:' => 'API endpoint:',
    'Refresh interval for personal board' => 'Oppdateringsintervall for privat tavleside',
    'Refresh interval for public board' => 'Oppdateringsintervall for offentlig tavleside',
    'Task highlight period' => 'Periode for fremheving av oppgaver',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Periode for å fastslå en oppgave nylig er endret (0 for å deaktivere, 2 dager er standard)',
    'Frequency in second (60 seconds by default)' => 'Frekevens i sekunder (60 sekunder som standard)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frekvens i sekunder (0 for å deaktivere denne funksjonen, 10 sekunder er standard)',
    'Application URL' => 'Applikasjon-URL',
    'Token regenerated.' => 'Token regenerert.',
    'Date format' => 'Datoformat',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO format, eksempel: "%s" og "%s"',
    'New personal project' => 'Nytt privat prosjekt',
    'This project is personal' => 'Dette projektet er privat',
    'Add' => 'Legg til',
    'Start date' => 'Startdato',
    'Time estimated' => 'Tid estimert',
    'There is nothing assigned to you.' => 'Ingen elementer er tildelt deg.',
    'My tasks' => 'Mine oppgaver',
    'Activity stream' => 'Aktivitetslogg',
    'Dashboard' => 'Hovedsiden',
    'Confirmation' => 'Bekreftelse',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Opprett en kommentar fra en ekstern tilbyder',
    'Project management' => 'Prosjektinnstillinger',
    'Columns' => 'Kolonner',
    'Task' => 'Oppgave',
    'Percentage' => 'Prosent',
    'Number of tasks' => 'Antall oppgaver',
    'Task distribution' => 'Kolonnefordeling',
    'Analytics' => 'Analyser',
    'Subtask' => 'Deloppgave',
    'User repartition' => 'Brukerfordeling',
    'Clone this project' => 'Kopier dette prosjektet',
    'Column removed successfully.' => 'Kolonne flyttet',
    'Not enough data to show the graph.' => 'Ikke nok data til å vise grafen',
    'Previous' => 'Forrige',
    'The id must be an integer' => 'ID må være heltall',
    'The project id must be an integer' => 'ProsjektID må være et heltall',
    'The status must be an integer' => 'Status må være et heltall',
    'The subtask id is required' => 'Du må angi ID for deloppgaven',
    'The subtask id must be an integer' => 'ID for deloppgaven må være et heltall',
    'The task id is required' => 'OppgaveID er påkrevet',
    'The task id must be an integer' => 'OppgaveID må være et heltall',
    'The user id must be an integer' => 'BrukerID må være et heltall',
    'This value is required' => 'Denne verdien er påkrevet',
    'This value must be numeric' => 'Verdien må være numerisk',
    'Unable to create this task.' => 'Kunne ikke opprette oppgaven',
    'Cumulative flow diagram' => 'Kumulativt flytdiagram',
    'Daily project summary' => 'Daglig prosjektsammendrag',
    'Daily project summary export' => 'Daglig prosjektsammendrag',
    'Exports' => 'Eksporter',
    'This export contains the number of tasks per column grouped per day.' => 'Denne eksporten inneholde antall oppgaver pr. kolonne gruppert pr. dag',
    'Active swimlanes' => 'Aktive svømmebaner',
    'Add a new swimlane' => 'Legg til en ny svømmebane',
    'Default swimlane' => 'Standard svømmebane',
    'Do you really want to remove this swimlane: "%s"?' => 'Er du sikker på at du vil fjerne svømmebane: "%s"?',
    'Inactive swimlanes' => 'Deaktiverte svømmebaner',
    'Remove a swimlane' => 'Fjern en svømmebane',
    'Swimlane modification for the project "%s"' => 'Svømmebane endrei i prosjektet "%s"',
    'Swimlane removed successfully.' => 'Svømmebane fjernet',
    'Swimlanes' => 'Svømmebaner',
    'Swimlane updated successfully.' => 'Svømmebane oppdatert',
    'Unable to remove this swimlane.' => 'Kunne ikke fjerne svømmebanen',
    'Unable to update this swimlane.' => 'Kunne ikke endre svømmebanen',
    'Your swimlane has been created successfully.' => 'Svømmebanen er opprettet!',
    'Example: "Bug, Feature Request, Improvement"' => 'Eksempel: Avvik, forbedringsforslag, ny funksjonalitet',
    'Default categories for new projects (Comma-separated)' => 'Standardkategorier for nye prosjekter (kommaseparert)',
    'Integrations' => 'Integrasjoner',
    'Integration with third-party services' => 'Integrasjoner med tredjeparts-tjenester',
    'Subtask Id' => 'Deloppgave ID',
    'Subtasks' => 'Deloppgaver',
    'Subtasks Export' => 'Eksporter deloppgaver',
    'Task Title' => 'Oppgavetittel',
    'Untitled' => 'Uten navn',
    'Application default' => 'Standardinstilling',
    'Language:' => 'Språk',
    'Timezone:' => 'Tidssone',
    'All columns' => 'Alle kolonner',
    'Next' => 'Neste',
    '#%d' => '#%d',
    'All swimlanes' => 'Alle svømmebaner',
    'All colors' => 'Alle farger',
    'Moved to column %s' => 'Flyttet til kolonne %s',
    'User dashboard' => 'Brukerens hovedside',
    'Allow only one subtask in progress at the same time for a user' => 'Tillat kun en aktiv deloppgave for brukerne',
    'Edit column "%s"' => 'Endre kolonne "%s"',
    'Select the new status of the subtask: "%s"' => 'Sett ny status for deloppgave: "%s"',
    'Subtask timesheet' => 'Tidsskjema for deloppgaver',
    'There is nothing to show.' => 'Ingen data å vise',
    'Time Tracking' => 'Tidsregistrering',
    'You already have one subtask in progress' => 'Du har allerede en aktiv deloppgave i dette prosjektet',
    'Which parts of the project do you want to duplicate?' => 'Hvilke deler av dette prosjektet ønsker du å kopiere?',
    'Disallow login form' => 'Deaktiver innloggingsbilde',
    'Start' => 'Start',
    'End' => 'Slutt',
    'Task age in days' => 'Antall dager siden siden oppgaven ble opprettet',
    'Days in this column' => 'Antall dager siden oppgaven ble lagt i denne kolonnen',
    '%dd' => '%dd',
    'Add a new link' => 'Legg til en ny relasjon',
    'Do you really want to remove this link: "%s"?' => 'Ønsker du virkelig å fjerne lenken: "%s"',
    'Do you really want to remove this link with task #%d?' => 'Ønsker du virkelig å fjerne lenken oppgaven #%d?',
    'Field required' => 'Feltet må fylles ut',
    'Link added successfully.' => 'Ny relasjon er lagt til',
    'Link updated successfully.' => 'Relasjon er oppdatert',
    'Link removed successfully.' => 'Relasjon er fjernet',
    'Link labels' => 'Relasjoner',
    'Link modification' => 'Relasjonsmodifisering',
    'Opposite label' => 'Etikett for relatert motsatt oppgave',
    'Remove a link' => 'Fjern relasjon',
    'The labels must be different' => 'Titlene må være ulike',
    'There is no link.' => 'Ingen lenker funnet',
    'This label must be unique' => 'Tittelen må være unik',
    'Unable to create your link.' => 'Kunne ikke opprette lenken.',
    'Unable to update your link.' => 'Kunne ikke endre lenken.',
    'Unable to remove this link.' => 'Kunne ikke fjerne lenken',
    'relates to' => 'relatert til',
    'blocks' => 'blokkerer',
    'is blocked by' => 'blokkeres av',
    'duplicates' => 'kopierer',
    'is duplicated by' => 'er en kopi av',
    'is a child of' => 'er en underordnet oppgave av',
    'is a parent of' => 'er en overordnet oppgave for',
    'targets milestone' => 'milepel',
    'is a milestone of' => 'er en milepel for',
    'fixes' => 'løser',
    'is fixed by' => 'løses av',
    'This task' => 'Denne oppgaven',
    '<1h' => '<1t',
    '%dh' => '%dt',
    'Expand tasks' => 'Utvid oppgavevisning',
    'Collapse tasks' => 'Komprimer oppgavevisning',
    'Expand/collapse tasks' => 'Utvide/komprimere oppgavevisning',
    'Close dialog box' => 'Lukk dialogvindu',
    'Submit a form' => 'Send inn skjema',
    'Board view' => 'Tavlevisning',
    'Keyboard shortcuts' => 'Hurtigtaster',
    'Open board switcher' => 'Åpne tavleskifter',
    'Application' => 'Applikasjon',
    'Compact view' => 'Kompakt visning',
    'Horizontal scrolling' => 'Bla horisontalt',
    'Compact/wide view' => 'Kompakt/bred visning',
    'Currency' => 'Valuta',
    'Personal project' => 'Privat prosjekt',
    'AUD - Australian Dollar' => 'AUD - Australske dollar',
    'CAD - Canadian Dollar' => 'CAD - Kanadiske dollar',
    'CHF - Swiss Francs' => 'CHF - Sveitsiske frank',
    'Custom Stylesheet' => 'Egendefinert stilark',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Britiske pund',
    'INR - Indian Rupee' => 'INR - Indiske rupi',
    'JPY - Japanese Yen' => 'JPY - Japanske yen',
    'NZD - New Zealand Dollar' => 'NZD - New Zealand Dollar',
    'PEN - Peruvian Sol' => 'PEN - Peruansk sol',
    'RSD - Serbian dinar' => 'RSD - Serbiske dinarer',
    'CNY - Chinese Yuan' => 'CNY - Kinesiske yuan',
    'USD - US Dollar' => 'USD - Amerikanske dollar',
    'VES - Venezuelan Bolívar' => 'VES - Venezuelansk bolívar',
    'Destination column' => 'Ny kolonne',
    'Move the task to another column when assigned to a user' => 'Flytt oppgaven til en annen kolonne når den er tildelt en bruker',
    'Move the task to another column when assignee is cleared' => 'Flytt oppgaven til en annen kolonne når ppgavetildeling fjernes ',
    'Source column' => 'Opprinnelig kolonne',
    'Transitions' => 'Statusendringer',
    'Executer' => 'Utfører',
    'Time spent in the column' => 'Medgått tid i kolonnen',
    'Task transitions' => 'Oppgavebevegelser',
    'Task transitions export' => 'Eksportere oppgavebevegelser',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Rapporten inneholder alle kolonnebevegelser for hver oppgave, med dato, bruker og tidsforbruk for hver bevegelse',
    'Currency rates' => 'Valutakurser',
    'Rate' => 'Kurs',
    'Change reference currency' => 'Endre refereransevaluta',
    'Reference currency' => 'Referansevaluta',
    'The currency rate has been added successfully.' => 'Referansevaluta er endret',
    'Unable to add this currency rate.' => 'Kan ikke legge til denne valutakursen',
    'Webhook URL' => 'Webhook URL',
    '%s removed the assignee of the task %s' => '%s fjernet ansvarlige for oppgaven %s',
    'Information' => 'Informasjon',
    'Check two factor authentication code' => 'Kontrollerer kode for tofaktor autensitering',
    'The two factor authentication code is not valid.' => 'Autentiseringskoden er ikke gyldig',
    'The two factor authentication code is valid.' => 'Autentiseringskoden er gyldig',
    'Code' => 'Kode',
    'Two factor authentication' => 'Tofaktor autentisering',
    'This QR code contains the key URI: ' => 'Denne QR-koden inneholder nøkkel URI: ',
    'Check my code' => 'Sjekk koden min',
    'Secret key: ' => 'Hemmelig nøkkel',
    'Test your device' => 'Test din enhet',
    'Assign a color when the task is moved to a specific column' => 'Endre til en valgt farge hvis en oppgave flyttes til en spesifikk kolonne',
    '%s via Kanboard' => '%s via Kanboard',
    'Burndown chart' => 'Burndown diagram',
    'This chart show the task complexity over the time (Work Remaining).' => 'Dette diagrammet viser oppgavekopleksitet over tid (gjenstående arbeid)',
    'Screenshot taken %s' => 'Skjemskudd lagt inn %s',
    'Add a screenshot' => 'Legg til et skjermbilde',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Ta et skjermskudd og trykk CTRL+V eller ⌘+V for å lime inn her.',
    'Screenshot uploaded successfully.' => 'Skjermbilde opplastet',
    'SEK - Swedish Krona' => 'SEK - Svenske kroner',
    'Identifier' => 'Prosjektkode',
    'Disable two factor authentication' => 'Slå av tofaktor autentisering',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Er du sikker på at du vil slå av tofaktor autentisering for bruker: "%s"?',
    'Edit link' => 'Endre lenke',
    'Start to type task title...' => 'Skriv in tittel',
    'A task cannot be linked to itself' => 'Oppgaver kan ikke lenkes til seg selv',
    'The exact same link already exists' => 'Denne lenken finnes fra før',
    'Recurrent task is scheduled to be generated' => 'Gjentagende oppgave vil bli opprettet',
    'Score' => 'Poeng',
    'The identifier must be unique' => 'Identifikatoren må være unik',
    'This linked task id doesn\'t exists' => 'Den lenkede oppgave-IDen finnes ikke',
    'This value must be alphanumeric' => 'Verdien må være alfanumerisk',
    'Edit recurrence' => 'Endre gjentakelser',
    'Generate recurrent task' => 'Opprett gjentagende oppgave',
    'Trigger to generate recurrent task' => 'Betingelse for å generere gjentakende oppgave',
    'Factor to calculate new due date' => 'Faktor for å beregne ny tidsfrist',
    'Timeframe to calculate new due date' => 'Tidsramme for å beregne ny tidsfrist',
    'Base date to calculate new due date' => 'Grunnlagsdato for å beregne ny tidsfrist',
    'Action date' => 'Hendelsesdato',
    'Base date to calculate new due date: ' => 'Grunnlagsdato for å beregne ny tidsfrist',
    'This task has created this child task: ' => 'Denne oppgaven har opprettet denne relaterte oppgaven',
    'Day(s)' => 'Dager',
    'Existing due date' => 'Gjeldende tidsfrist',
    'Factor to calculate new due date: ' => 'Faktor for å beregne ny tidsfrist',
    'Month(s)' => 'Måneder',
    'This task has been created by: ' => 'Denne oppgaven er opprettet av:',
    'Recurrent task has been generated:' => 'Repeterende oppgave er opprettet',
    'Timeframe to calculate new due date: ' => 'Tidsrom for beregning av ny tidsfrist: ',
    'Trigger to generate recurrent task: ' => 'Trigger for å generere gjentagende oppgave: ',
    'When task is closed' => 'Når oppgaven er lukket',
    'When task is moved from first column' => 'Når oppgaven er flyttet fra første kolon',
    'When task is moved to last column' => 'Når oppgaven er flyttet til siste kolonne',
    'Year(s)' => 'år',
    'Project settings' => 'Prosjektinnstillinger',
    'Automatically update the start date' => 'Oppdater automatisk start-datoen',
    'iCal feed' => 'iCal strøm',
    'Preferences' => 'Preferanser',
    'Security' => 'Sikkerhet',
    'Two factor authentication disabled' => 'Dobbelgodkjenning deaktivert',
    'Two factor authentication enabled' => 'Dobbelgodkjenning aktivert',
    'Unable to update this user.' => 'Kan ikke oppdatere brukeren',
    'There is no user management for personal projects.' => 'Private prosjekter har ikke brukeradministrasjon',
    'User that will receive the email' => 'Bruker som vil motta den nye e-posten',
    'Email subject' => 'E-post emne',
    'Date' => 'Dato',
    'Add a comment log when moving the task between columns' => 'Legg til en kommentar i loggen når en oppgave flyttes mellom kolonnene',
    'Move the task to another column when the category is changed' => 'Flytt oppgaven til en annen kolonne når kategorien endres',
    'Send a task by email to someone' => 'Send en oppgave på epost til noen',
    'Reopen a task' => 'Gjenåpne oppgave',
    'Notification' => 'Varsel',
    '%s moved the task #%d to the first swimlane' => '%s  flyttet oppgaven #%d til første svømmebane',
    'Swimlane' => 'Svømmebane',
    '%s moved the task %s to the first swimlane' => '%s flyttet oppgaven %s til første svømmebane',
    '%s moved the task %s to the swimlane "%s"' => '%s flyttet oppgaven %s til svømmebanen "%s"',
    'This report contains all subtasks information for the given date range.' => 'Rapporten viser informasjon om alle deloppgaver for valgte tidsrom.',
    'This report contains all tasks information for the given date range.' => 'Rapporten inneholder informasjon om alle oppgaver for valgte tidsrom',
    'Project activities for %s' => 'Prosjektaktiviteter for %s',
    'view the board on Kanboard' => 'vis tavlen',
    'The task has been moved to the first swimlane' => 'Oppgaven er flyttet til første svømmebane',
    'The task has been moved to another swimlane:' => 'Oppgaven er flyttet til en annen svømmebane:',
    'New title: %s' => 'Ny tittel: %s',
    'The task is not assigned anymore' => 'Oppgaven har ikke lenger noen ansvarlig',
    'New assignee: %s' => 'Ny ansvarlig: %s',
    'There is no category now' => 'Ingen kategori nå',
    'New category: %s' => 'Ny kategori: %s',
    'New color: %s' => 'Ny farge: %s',
    'New complexity: %d' => 'Ny kompleksitet: %d',
    'The due date has been removed' => 'Fristdato er fjernet',
    'There is no description anymore' => 'Ikke lenger noen beskrivelse',
    'Recurrence settings has been modified' => 'Instillinger for gjentagelse er endret',
    'Time spent changed: %sh' => 'Tidsforbruk er endret: %sh',
    'Time estimated changed: %sh' => 'Tidsestimat er endret: %sh',
    'The field "%s" has been updated' => 'Feltet "%s" er oppdatert',
    'The description has been modified:' => 'Beskrivelsen er endret',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Ønsker du virkelig å lukke oppgaven "%s" og alle tilhørende deloppgaver?',
    'I want to receive notifications for:' => 'Jeg vil motta varslinger om:',
    'All tasks' => 'Alle oppgaver',
    'Only for tasks assigned to me' => 'Kun oppgaver som er tildelt meg',
    'Only for tasks created by me' => 'Kun oppgaver som er opprettet av meg',
    'Only for tasks created by me and tasks assigned to me' => 'Kun oppgaver som er opprettet av meg og tildelt meg',
    '%%Y-%%m-%%d' => '%%d-%%m-%%Y',
    'Total for all columns' => 'Totalt for alle kolonner',
    'You need at least 2 days of data to show the chart.' => 'Du må ha minimum 2 dager med data for å kunne se dette diagrammet',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Stopp timer',
    'Start timer' => 'Start timer',
    'My activity stream' => 'Aktivitetslogg',
    'Search tasks' => 'Søk oppgave',
    'Reset filters' => 'Nullstill filter',
    'My tasks due tomorrow' => 'Mine oppgaver med frist i morgen',
    'Tasks due today' => 'Oppgaver med frist i dag',
    'Tasks due tomorrow' => 'Oppgaver med frist i morgen',
    'Tasks due yesterday' => 'Oppgaver med frist i går',
    'Closed tasks' => 'Fullførte oppgaver',
    'Open tasks' => 'Åpne oppgaver',
    'Not assigned' => 'Ikke tildelt',
    'View advanced search syntax' => 'Vis hjelp for avansert søk ',
    'Overview' => 'Oversikt',
    'Board/Calendar/List view' => 'Oversikt/kalender/listevisning',
    'Switch to the board view' => 'Oversiktsvisning',
    'Switch to the list view' => 'Listevisning',
    'Go to the search/filter box' => 'Gå til søk/filter',
    'There is no activity yet.' => 'Ingen aktiviteter ennå.',
    'No tasks found.' => 'Ingen oppgaver funnet',
    'Keyboard shortcut: "%s"' => 'Hurtigtaster: "%s"',
    'List' => 'Liste',
    'Filter' => 'Filter',
    'Advanced search' => 'Avansert søk',
    'Example of query: ' => 'Eksempel på spørring',
    'Search by project: ' => 'Søk etter prosjekt',
    'Search by column: ' => 'Søk etter kolonne',
    'Search by assignee: ' => 'Søk etter tildelt',
    'Search by color: ' => 'Søk etter farge',
    'Search by category: ' => 'Søk etter kategori',
    'Search by description: ' => 'Søk etter beskrivelse',
    'Search by due date: ' => 'Søk etter frist',
    'Average time spent in each column' => 'Gjennomsnittlig tid i hver kolonne',
    'Average time spent' => 'Gjennomsnittlig tidsbruk',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Dette diagrammet viser gjennomsnittlig tid i hver kolonne for de siste %d oppgavene.',
    'Average Lead and Cycle time' => 'Gjennomsnittlig ledetid og syklustid',
    'Average lead time: ' => 'Gjennomsnittlig ledetid',
    'Average cycle time: ' => 'Gjennomsnitlig syklustid',
    'Cycle Time' => 'Syklustid',
    'Lead Time' => 'Ledetid',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Dette diagrammet viser gjennomsnittlig ledetid og syklustid for de siste %d oppgavene.',
    'Average time into each column' => 'Gjennomsnittlig tid i hver kolonne',
    'Lead and cycle time' => 'Ledetid og syklustid',
    'Lead time: ' => 'Ledetid',
    'Cycle time: ' => 'Syklustid',
    'Time spent in each column' => 'Tid brukt i hver kolonne',
    'The lead time is the duration between the task creation and the completion.' => 'Ledetid er tidsrommet fra oppgaven opprettes til den er fullført',
    'The cycle time is the duration between the start date and the completion.' => 'Syklustid er tidsrommet fra oppgaven starter til den er fullført',
    'If the task is not closed the current time is used instead of the completion date.' => 'Dersom oppgaven ikke er lukket brukes dagens dato i stedet for fullført dato.',
    'Set the start date automatically' => 'Sett startdato automatisk',
    'Edit Authentication' => 'Endre autentisering',
    'Remote user' => 'Ekstern bruker',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Eksterne brukere har ikke passordet lagret i Kanboard. Eksempel: LDAP, Google og Github-kontoer.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Hvis du har krysset av for  "Deaktiver innloggingsbilde" vil opplysninger som tastes inn i innloggingsskjemaet bli ignorert',
    'Default task color' => 'Standard oppgavefarge',
    'This feature does not work with all browsers.' => 'Denne funksjonen virker ikke i alle nettlesere',
    'There is no destination project available.' => 'Finner ikke noe målprosjekt',
    'Trigger automatically subtask time tracking' => 'Automatisk tidsforbruk for deloppgaver',
    'Include closed tasks in the cumulative flow diagram' => 'Ta med lukkede oppgaver i kumulativt flytdiagram',
    'Current swimlane: %s' => 'Nåværende svømmebane: %s',
    'Current column: %s' => 'Nåværende kolonne: %s',
    'Current category: %s' => ': %s',
    'no category' => 'ingen kategori',
    'Current assignee: %s' => 'Tildelt til %s',
    'not assigned' => 'ikke tildelt',
    'Author:' => 'Opprettet av',
    'contributors' => 'bidragsytere',
    'License:' => 'Lisens:',
    'License' => 'Lisens',
    'Enter the text below' => 'Skriv inn bokstavene du ser i bildet',
    'Start date:' => 'Startdato:',
    'Due date:' => 'Frist:',
    'People who are project managers' => 'Prosjektledere',
    'People who are project members' => 'Prosjektmedlemmer',
    'NOK - Norwegian Krone' => 'NOK - Norske kroner',
    'Show this column' => 'Vis denne kolonnen',
    'Hide this column' => 'Skjul denne kolonnen',
    'End date' => 'Sluttdato',
    'Users overview' => 'Brukeroversikt',
    'Members' => 'Medlemmer',
    'Shared project' => 'Delt prosjekt',
    'Project managers' => 'Prosjektledere',
    'Projects list' => 'Prosjektliste',
    'End date:' => 'Sluttdato:',
    'Change task color when using a specific task link' => 'Endre oppgavefarge når det brukes en definert oppgavelenke',
    'Task link creation or modification' => 'Oppgavelenke opprettet eller endret',
    'Milestone' => 'Milepæl',
    'Reset the search/filter box' => 'Nullstill søk/filter',
    'Documentation' => 'Dokumentasjon',
    'Author' => 'Forfatter',
    'Version' => 'Versjon',
    'Plugins' => 'Innstikk',
    'There is no plugin loaded.' => 'Ingen innstikk er lastet',
    'My notifications' => 'Mine varslinger',
    'Custom filters' => 'Egendefinerte filtre',
    'Your custom filter has been created successfully.' => 'Egendefinert filter er opprettet.',
    'Unable to create your custom filter.' => 'Feil ved oppretting av egendefinert filter.',
    'Custom filter removed successfully.' => 'Egendefinert filter er slettet.',
    'Unable to remove this custom filter.' => 'Feil ved sletting av egendefinert filter.',
    'Edit custom filter' => 'Endre egendefinert filter',
    'Your custom filter has been updated successfully.' => 'Egendefinert filter er endret.',
    'Unable to update custom filter.' => 'Feil ved endring av egendefinert filter.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Nytt vedlegg til oppgaven #%d: %s',
    'New comment on task #%d' => 'Ny kommentar på oppgaven #%d',
    'Comment updated on task #%d' => 'Kommentar endret for oppgaven #%d',
    'New subtask on task #%d' => 'Ny deloppgave for oppgaven #%d',
    'Subtask updated on task #%d' => 'Deloppgave er endret for oppgave #%d',
    'New task #%d: %s' => 'Ny oppgave #%d: %s',
    'Task updated #%d' => 'Oppgaven #%d er endret',
    'Task #%d closed' => 'Oppgaven #%d er lukket',
    'Task #%d opened' => 'Oppgaven #%d er åpnet',
    'Column changed for task #%d' => 'Kolonne endret for oppgaven #%d',
    'New position for task #%d' => 'Ny posisjon for oppgaven #%d',
    'Swimlane changed for task #%d' => 'Svømmebane er endret for oppgaven #%d',
    'Assignee changed on task #%d' => 'Ansvarlig er endret for oppgaven #%d',
    '%d overdue tasks' => '%d forfalte oppgaver',
    'No notification.' => 'Ingen varslinger',
    'Mark all as read' => 'Merk alle som lest',
    'Mark as read' => 'Merk som lest',
    'Total number of tasks in this column across all swimlanes' => 'Totalt antall oppgaver i denne kolonnen gjennom alle svømmebaner',
    'Collapse swimlane' => 'Slå sammen svømmebanen',
    'Expand swimlane' => 'Fold ut svømmebane',
    'Add a new filter' => 'Lag nytt filter',
    'Share with all project members' => 'Del med alle prosjektdeltagere',
    'Shared' => 'Delt',
    'Owner' => 'Eier',
    'Unread notifications' => 'Uleste varslinger',
    'Notification methods:' => 'Varslingsmetoder',
    'Unable to read your file' => 'Kan ikke lese filen',
    '%d task(s) have been imported successfully.' => '%d oppgave(r) er importert.',
    'Nothing has been imported!' => 'Ingenting ble importert!',
    'Import users from CSV file' => 'Importere brukere fra CSV-fil',
    '%d user(s) have been imported successfully.' => '%d bruker(e) er imporert.',
    'Comma' => 'Komma',
    'Semi-colon' => 'Semikolon',
    'Tab' => 'Tabulator',
    'Vertical bar' => 'Loddrett strek',
    'Double Quote' => 'Rett sitattegn',
    'Single Quote' => 'Rett apostrof',
    '%s attached a file to the task #%d' => '%s la ved en fil til oppgaven #%d',
    'There is no column or swimlane activated in your project!' => 'Prosjektet har ingen aktive kolonner eller svømmebaner!',
    'Append filter (instead of replacement)' => 'Tilføy filter (i stedet for å erstatte)',
    'Append/Replace' => 'Tilføu/erstatt',
    'Append' => 'Tilføy',
    'Replace' => 'Erstatt',
    'Import' => 'Importer',
    'Change sorting' => 'Endre sortering',
    'Tasks Importation' => 'Importere oppgaver',
    'Delimiter' => 'Feltavgrenser',
    'Enclosure' => 'Streng skilletegn',
    'CSV File' => 'CSV-fil',
    'Instructions' => 'Instruksjoner',
    'Your file must use the predefined CSV format' => 'Filen må ha et forhåndsdefinert CSV-format',
    'Your file must be encoded in UTF-8' => 'Filen må være kodet i UTF-8',
    'The first row must be the header' => 'Første rad må være overskrifter',
    'Duplicates are not verified for you' => 'Det blir ikke sjekket for duplikater',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Tidsfrister må angis i ISO-format: ÅÅÅÅ-MM-DD',
    'Download CSV template' => 'Last ned en CSV-mal',
    'No external integration registered.' => 'Ingen ekstern intergasjon er registrert',
    'Duplicates are not imported' => 'Duplikater importeres ikke',
    'Usernames must be lowercase and unique' => 'Brukernavn må være unike og skrevet i små bokstaver',
    'Passwords will be encrypted if present' => 'Eventuelt oppgitte passord vil blir kryptert',
    '%s attached a new file to the task %s' => '%s la ved en ny fil til oppgaven %s',
    'Link type' => 'Relasjonstype',
    'Assign automatically a category based on a link' => 'Tildel kategori automatisk basert på lenke',
    'BAM - Konvertible Mark' => 'BAM - Bosniske mark',
    'Assignee Username' => 'Brukernavn ansvarlig',
    'Assignee Name' => 'Fullt navn ansvarlig',
    'Groups' => 'Grupper',
    'Members of %s' => 'Medlemmer av %s',
    'New group' => 'Ny gruppe',
    'Group created successfully.' => 'Gruppen er opprettet',
    'Unable to create your group.' => 'Kunne ikke opprette gruppen',
    'Edit group' => 'Endre gruppe',
    'Group updated successfully.' => 'Gruppen er endret',
    'Unable to update your group.' => 'Kunne ikke endre gruppen',
    'Add group member to "%s"' => 'Legg gruppemedlem til "%s"',
    'Group member added successfully.' => 'Gruppemedlem lagt til',
    'Unable to add group member.' => 'Kunne ikke legge til gruppemedlem',
    'Remove user from group "%s"' => 'Fjern bruker fra gruppen "%s"',
    'User removed successfully from this group.' => 'Bruker er fjernet fra denne gruppen.',
    'Unable to remove this user from the group.' => 'Kunne ikke fjerne bruker fra gruppen.',
    'Remove group' => 'Fjern gruppe',
    'Group removed successfully.' => 'Gruppen er fjernet',
    'Unable to remove this group.' => 'Kunne ikke fjerne gruppen',
    'Project Permissions' => 'Prosjektrettigheter',
    'Manager' => 'Leder',
    'Project Manager' => 'Prosjektleder',
    'Project Member' => 'Prosjektdeltager',
    'Project Viewer' => 'Kun lesetilgang',
    'Your account is locked for %d minutes' => 'Kontoen din vil være låst i %d minutter',
    'Invalid captcha' => 'Ugyldig captcha',
    'The name must be unique' => 'Navnet må være unikt',
    'View all groups' => 'Vis alle grupper',
    'There is no user available.' => 'Ingen tilgjengelig bruker',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Ønsker du virkelig å fjerne bruker "%s" fra gruppen "%s"?',
    'There is no group.' => 'Ingen grupper opprettet',
    'Add group member' => 'Legg til medlem',
    'Do you really want to remove this group: "%s"?' => 'Ønsker du virkelig å fjerne gruppen "%s"',
    'There is no user in this group.' => 'Gruppen har ingen medlemmer',
    'Permissions' => 'Rettigheter',
    'Allowed Users' => 'Brukere med tilgang',
    'No specific user has been allowed.' => 'Ingen brukere er lagt inn foreløpig',
    'Role' => 'Rolle',
    'Enter user name...' => 'Skriv brukenavn',
    'Allowed Groups' => 'Brukergrupper med tilgang',
    'No group has been allowed.' => 'Ingen brukergrupper er lagt inn foreløpig',
    'Group' => 'Gruppe',
    'Group Name' => 'Gruppenavn',
    'Enter group name...' => 'Skriv gruppenavn',
    'Role:' => 'Rolle',
    'Project members' => 'Prosjektmedlemmer',
    '%s mentioned you in the task #%d' => '%s nevnte deg i oppgaven #%d',
    '%s mentioned you in a comment on the task #%d' => '%s nevnte deg i en kommentar på oppgaven #%d',
    'You were mentioned in the task #%d' => 'Du ble nevnt i oppgaven #%d',
    'You were mentioned in a comment on the task #%d' => 'Du ble nevnt i en kommentar på oppgaven #%d',
    'Estimated hours: ' => 'Estimerte timer:',
    'Actual hours: ' => 'Faktisk medgåtte timer',
    'Hours Spent' => 'Brukt timer',
    'Hours Estimated' => 'Estimerte timer',
    'Estimated Time' => 'Estimert tid',
    'Actual Time' => 'Medgått tid',
    'Estimated vs actual time' => 'Estimert mot virkelig tid',
    'RUB - Russian Ruble' => 'RUB - Russiske rubler',
    'Assign the task to the person who does the action when the column is changed' => 'Tildel oppgaven til personen som flytter den til en annen kolonne',
    'Close a task in a specific column' => 'Lukk en oppgave i en angitt kolonne',
    'Time-based One-time Password Algorithm' => 'Algoritme for tidsbasert engangspassord',
    'Two-Factor Provider: ' => 'Tofaktorleverandør:',
    'Disable two-factor authentication' => 'Deaktiver tofaktorautentisering',
    'Enable two-factor authentication' => 'Aktiver tofaktorautentisering',
    'There is no integration registered at the moment.' => 'Ingen registrert integrasjon.',
    'Password Reset for Kanboard' => 'Nytt passord til Kanboard',
    'Forgot password?' => 'Glemt passord?',
    'Enable "Forget Password"' => 'Bruk "Glemt passord"',
    'Password Reset' => 'Nytt passord',
    'New password' => 'Nytt passord',
    'Change Password' => 'Endre passord',
    'To reset your password click on this link:' => 'Bruk denne lenken for å tilbakestille passordet ditt:',
    'Last Password Reset' => 'Forrige passordendring',
    'The password has never been reinitialized.' => 'Passordet er aldri blitt endret',
    'Creation' => 'Opprettet',
    'Expiration' => 'Utløper',
    'Password reset history' => 'Passordhistorikk',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Alle oppgaver i kolonne "%s" og svømmebane "%s" er lukket.',
    'Do you really want to close all tasks of this column?' => 'Ønsker du virkelig å lukke ALLE saker i kolonnen?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d oppgave(r) i kolonne "%s" og svømmebane "%s" vil bli lukket.',
    'Close all tasks in this column and this swimlane' => 'Lukk alle saker i denne kolonnen',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Det finnes ingen innstikk for prosjektvarsling. Du kan likevel sette opp individuelle varslinger i brukerprofilen din.',
    'My dashboard' => 'Mitt dashbord',
    'My profile' => 'Min profil',
    'Project owner: ' => 'Prosjekteier: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Du kan lage en valgfri, alfanumerisk prosjektkode — for eksempel MITTPROSJEKT',
    'Project owner' => 'Prosjekteier',
    'Personal projects do not have users and groups management.' => 'Private prosjekter har ikke brukere eller gruppeadministrasjon',
    'There is no project member.' => 'Ingen prosjektmedlemmer',
    'Priority' => 'Prioritet',
    'Task priority' => 'Prioritet',
    'General' => 'Generelt',
    'Dates' => 'Datoer',
    'Default priority' => 'Standard',
    'Lowest priority' => 'Lav',
    'Highest priority' => 'Høy',
    'Close a task when there is no activity' => 'Lukk enoppgave når det ikke er noen aktivitet',
    'Duration in days' => 'Varighet i dager',
    'Send email when there is no activity on a task' => 'Send e-post når det ikke er noen aktivitet på en oppgave',
    'Unable to fetch link information.' => 'Kan ikke hente lenkeinformasjon',
    'Daily background job for tasks' => 'Daglig bakgrunnsjobb for oppgaver',
    'Auto' => 'Auto',
    'Related' => 'Relasjon',
    'Attachment' => 'Vedlegg',
    'Title not found' => 'Finner ingen tittel',
    'Web Link' => 'Web-lenke',
    'External links' => 'Eksterne lenker',
    'Add external link' => 'Ny ekstern lenke',
    'Type' => 'Type',
    'Dependency' => 'Avhenger av',
    'Add internal link' => 'Lag intern lenke',
    'Add a new external link' => 'Lag ekstern lenke',
    'Edit external link' => 'Endre ekstern lenke',
    'External link' => 'Ekstern lenke',
    'Copy and paste your link here...' => 'Kopier lenken og lim den inn her',
    'URL' => 'URL',
    'Internal links' => 'Interne lenker',
    'Assign to me' => 'Tildel denne til meg',
    'Me' => 'Meg',
    'Do not duplicate anything' => 'Ingen duplisering',
    'Projects management' => 'Prosjektadministrasjon',
    'Users management' => 'Brukeradministrasjon',
    'Groups management' => 'Gruppeadministrasjon',
    'Create from another project' => 'Lag fra et annet prosjekt',
    'open' => 'åpen',
    'closed' => 'lukket',
    'Priority:' => 'Prioritet',
    'Reference:' => 'Referanse',
    'Complexity:' => 'Kompleksitet',
    'Swimlane:' => 'Svømmebane',
    'Column:' => 'Kolonne',
    'Position:' => 'Posisjon',
    'Creator:' => 'Opprettet av',
    'Time estimated:' => 'Estimert tidsforbruk',
    '%s hours' => '%s timer',
    'Time spent:' => 'Medgått tid',
    'Created:' => 'Opprettet',
    'Modified:' => 'Endret',
    'Completed:' => 'Fullført',
    'Started:' => 'Startet:',
    'Moved:' => 'Flyttet:',
    'Task #%d' => 'Oppgave #%d',
    'Time format' => 'Tidsformat',
    'Start date: ' => 'Startdato:',
    'End date: ' => 'Sluttdato:',
    'New due date: ' => 'Ny frist:',
    'Start date changed: ' => 'Startdato endret:',
    'Disable personal projects' => 'Deaktiver mulighet for private prosjekter',
    'Do you really want to remove this custom filter: "%s"?' => 'Ønsker du virkelig å fjerne det egendefinerte filteret: "%s"?',
    'Remove a custom filter' => 'Fjern egendefinert filter',
    'User activated successfully.' => 'Brukeren er aktivert.',
    'Unable to enable this user.' => 'Kan ikke aktivere brukeren.',
    'User disabled successfully.' => 'Brukeren er deaktivert.',
    'Unable to disable this user.' => 'Kan ikke deaktivere brukeren.',
    'All files have been uploaded successfully.' => 'Alle filer er lastet opp.',
    'The maximum allowed file size is %sB.' => 'Maks. tillatte filstørrelse er %sB',
    'Drag and drop your files here' => 'Dra og slipp filene her',
    'choose files' => 'velg filer',
    'View profile' => 'Vis profil',
    'Two Factor' => 'Tofaktor',
    'Disable user' => 'Deaktiver bruker',
    'Do you really want to disable this user: "%s"?' => 'Ønsker du virkelig å DEAKTIVERE denne brukeren: "%s"?',
    'Enable user' => 'Aktiver bruker',
    'Do you really want to enable this user: "%s"?' => 'Ønsker du virkelig å AKTIVERE denne brukeren: "%s"?',
    'Download' => 'Last ned',
    'Uploaded: %s' => 'Lastet opp: %s',
    'Size: %s' => 'Størrelse: %s',
    'Uploaded by %s' => 'Lastet opp av %s',
    'Filename' => 'Filnavn',
    'Size' => 'Størrelse',
    'Column created successfully.' => 'Kolonnen er opprettet',
    'Another column with the same name exists in the project' => 'Kolonnen finnes allerede i dette prosjektet',
    'Default filters' => 'Standardfiltere',
    'Your board doesn\'t have any columns!' => 'Tavlen har ingen kolonner!',
    'Change column position' => 'Endre kolonneplassering',
    'Switch to the project overview' => 'Bytt til prosjektoversikt',
    'User filters' => 'Brukerfilter',
    'Category filters' => 'Kategorifiltere',
    'Upload a file' => 'Last opp fil',
    'View file' => 'Vis fil',
    'Last activity' => 'Nyeste aktivitet',
    'Change subtask position' => 'Endre posisjon for deloppgave',
    'This value must be greater than %d' => 'Verdien må være større en %d',
    'Another swimlane with the same name exists in the project' => 'Denne svømmebanen finnes allerede i dette prosjektet',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Eksempel: https://eksempel.kanboard.org/ (brukes for å lage absolutte URLer)',
    'Actions duplicated successfully.' => 'Handlinger er duplisert.',
    'Unable to duplicate actions.' => 'Feil ved duplisering av handlinger.',
    'Add a new action' => 'Ny automatisk handling',
    'Import from another project' => 'Importer fra et annet prosjekt',
    'There is no action at the moment.' => 'Ingen automatiske handlinger',
    'Import actions from another project' => 'Importer handlinger fra et annet prosjekt',
    'There is no available project.' => 'Ingen prosjekter',
    'Local File' => 'Lokal fil',
    'Configuration' => 'Konfigurasjon',
    'PHP version:' => 'PHP versjon:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'OS versjon',
    'Database version:' => 'Databaseversjon',
    'Browser:' => 'Nettleser',
    'Task view' => 'Vis oppgave',
    'Edit task' => 'Endre oppgave',
    'Edit description' => 'Endre beskrivelse',
    'New internal link' => 'Ny intern lenke',
    'Display list of keyboard shortcuts' => 'Oversikt over tastatursnarveier',
    'Avatar' => 'Profilbilde',
    'Upload my avatar image' => 'Last opp profilbilde',
    'Remove my image' => 'Fjern profilbilde',
    'The OAuth2 state parameter is invalid' => 'Feil parameter for OAuth2 tilstand',
    'User not found.' => 'Bruker ikke funnet',
    'Search in activity stream' => 'Søk i aktivitetsstrøm',
    'My activities' => 'Mine aktiviteter',
    'Activity until yesterday' => 'Aktivitet fram til i går',
    'Activity until today' => 'Aktivitet fram til i  dag',
    'Search by creator: ' => 'Søk > Opprettet av:',
    'Search by creation date: ' => 'Søk > Opprettet dato:',
    'Search by task status: ' => 'Søk > Oppgavestatus',
    'Search by task title: ' => 'Søk > Oppgavetittel',
    'Activity stream search' => 'Søk > Aktivitetsstrøm',
    'Projects where "%s" is manager' => 'Prosjekter hvor "%s" er prosjektleder',
    'Projects where "%s" is member' => 'Prosjekter hvor "%s" er medlem',
    'Open tasks assigned to "%s"' => 'Åpne oppgaver tildelt "%s"',
    'Closed tasks assigned to "%s"' => 'Lukkede oppgaver tildelt "%s"',
    'Assign automatically a color based on a priority' => 'Tilordne farge automatisk ut fra prioritet',
    'Overdue tasks for the project(s) "%s"' => 'Forsinkede oppgaver for prosjekt(ene) "%s"',
    'Upload files' => 'Last opp filer',
    'Installed Plugins' => 'Installerte innstikk',
    'Plugin Directory' => 'Instikk (katalog)',
    'Plugin installed successfully.' => 'Innstikket er installert',
    'Plugin updated successfully.' => 'Innstikket er oppdatert',
    'Plugin removed successfully.' => 'Innstikket er fjernet',
    'Subtask converted to task successfully.' => 'Deloppgaven er konvertert til en oppgave',
    'Unable to convert the subtask.' => 'Kunne ikke konvertere deloppgaven',
    'Unable to extract plugin archive.' => 'Feil ved utpakking av innstikk',
    'Plugin not found.' => 'Finner ikke innstikk',
    'You don\'t have the permission to remove this plugin.' => 'Du har ikke rettigheter til å fjerne dette innstikket',
    'Unable to download plugin archive.' => 'Feil ved nedlasting av innstikk',
    'Unable to write temporary file for plugin.' => 'Feil ved skriving av midlertidige filer for innstikket',
    'Unable to open plugin archive.' => 'Feil ved åpning av innstikk',
    'There is no file in the plugin archive.' => 'Innstikket inneholder ingen filer!',
    'Create tasks in bulk' => 'Masseoppretting av saker',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Denne Kanboardinstallasjonen er ikke satt opp for å legge til innstikk fra brukergrensensnittet.',
    'There is no plugin available.' => 'Finner ingen innstikk',
    'Install' => 'Installer',
    'Update' => 'Oppdater',
    'Up to date' => 'Ajour',
    'Not available' => 'Ikke tilgjengelig',
    'Remove plugin' => 'Fjern innstikk',
    'Do you really want to remove this plugin: "%s"?' => 'Er du sikker på at du vil fjerne innstikket "%s"?',
    'Uninstall' => 'Avinstaller',
    'Listing' => 'Oversikt',
    'Metadata' => 'Metadata',
    'Manage projects' => 'Administrere prosjekter',
    'Convert to task' => 'Gjør om til oppgave',
    'Convert sub-task to task' => 'Gjør om deloppgave til oppgave',
    'Do you really want to convert this sub-task to a task?' => 'Er du sikker på at du vil gjøre om denne deloppgaven til en oppgave?',
    'My task title' => 'Oppgavetittel',
    'Enter one task by line.' => 'Du kan skrive inn en oppgave pr rad',
    'Number of failed login:' => 'Antall feilede loginforsøk:',
    'Account locked until:' => 'Kontoen er låst til:',
    'Email settings' => 'E-post',
    'Email sender address' => 'Avsenderadresse (e-post):',
    'Email transport' => 'E-post metode',
    'Webhook token' => 'Webhook token',
    'Project tags management' => 'Etiketter',
    'Tag created successfully.' => 'Etiketten er opprettet',
    'Unable to create this tag.' => 'Kunne ikke opprette etiketten',
    'Tag updated successfully.' => 'Etiketten er endret',
    'Unable to update this tag.' => 'Kunne ikke endre etiketten',
    'Tag removed successfully.' => 'Etiketten er slettet',
    'Unable to remove this tag.' => 'Kunne ikke slette etiketten',
    'Global tags management' => 'Administrere globale etiketter',
    'Tags' => 'Etiketter',
    'Tags management' => 'Etiketter',
    'Add new tag' => 'Ny etikett',
    'Edit a tag' => 'Endre etikett',
    'Project tags' => 'Etiketter',
    'There is no specific tag for this project at the moment.' => 'Prosjektet har for tiden ingen etiketter',
    'Tag' => 'Etikett',
    'Remove a tag' => 'Fjern etikett',
    'Do you really want to remove this tag: "%s"?' => 'Er du sikker på at du vil fjerne etiketten: "%s"?',
    'Global tags' => 'Globale etiketter',
    'There is no global tag at the moment.' => 'Ingen globale etiketter',
    'This field cannot be empty' => 'Dette feltet kan ikke være tomt',
    'Close a task when there is no activity in a specific column' => 'Lukk oppgaven når det ikke er aktivitet i en angitt kolonne',
    '%s removed a subtask for the task #%d' => '%s slettet en deloppgave for oppgaven #%d',
    '%s removed a comment on the task #%d' => '%s slettet en kommentar på oppgaven #%d',
    'Comment removed on task #%d' => 'Kommentar slettet fra oppgave #%d',
    'Subtask removed on task #%d' => 'Deloppgave slettet fra oppgave #%d',
    'Hide tasks in this column in the dashboard' => 'Ikke vis oppgaver i denne kolonnen på dashbordet',
    '%s removed a comment on the task %s' => '%s slettet en kommentar på oppgaven %s',
    '%s removed a subtask for the task %s' => '%s slettet en deloppgave for oppgaven %s',
    'Comment removed' => 'Kommentaren er fjernet',
    'Subtask removed' => 'Deloppgaven er slettet',
    '%s set a new internal link for the task #%d' => '%s lagde en internlenke på oppgaven #%d',
    '%s removed an internal link for the task #%d' => '%s fjernet en internlenke på oppgaven #%d',
    'A new internal link for the task #%d has been defined' => 'Det er laget en ny internlenke for oppgaven #%d',
    'Internal link removed for the task #%d' => 'Internlenke fjernet på oppgaven #%d',
    '%s set a new internal link for the task %s' => '%s laget en ny internlenke for oppgaven %s',
    '%s removed an internal link for the task %s' => '%s fjernet en internlenke for opgaven %s',
    'Automatically set the due date on task creation' => 'Sett tidsfrist automatisk ved opprettelse av oppgave',
    'Move the task to another column when closed' => 'Flytt oppgaven til en annen kolonne når den lukkes',
    'Move the task to another column when not moved during a given period' => 'Flytt oppgaven til en annen kolonne når den ikke flyttes i et gitt tidsrom',
    'Dashboard for %s' => 'Dashbord for %s',
    'Tasks overview for %s' => 'Oppgaveoversikt for %s',
    'Subtasks overview for %s' => 'Deloppgaver for %s',
    'Projects overview for %s' => 'Prosjektoversikt for %s',
    'Activity stream for %s' => 'Aktivitetsstrøm for %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Tilordne farge når oppgaven flyttes til angitt svømmebane',
    'Assign a priority when the task is moved to a specific swimlane' => 'Tilordne prioritet når oppgaven flyttes til angitt svømmebane',
    'User unlocked successfully.' => 'Brukeren er låst opp',
    'Unable to unlock the user.' => 'Kunne ikke låse opp brukeren',
    'Move a task to another swimlane' => 'Flytt oppgaven til en annen svømmebane',
    'Creator Name' => 'Opprettet av',
    'Time spent and estimated' => 'Estimert og medgått tid',
    'Move position' => 'Endre posisjon',
    'Move task to another position on the board' => 'Flytt oppgaven',
    'Insert before this task' => 'Sett inn før denne oppgaven',
    'Insert after this task' => 'Sett inn etter denne oppgaven',
    'Unlock this user' => 'Lås opp bruker',
    'Custom Project Roles' => 'Egendefinerte prosjektroller',
    'Add a new custom role' => 'Ny egendefinert rolle',
    'Restrictions for the role "%s"' => 'Restriksjoner for rollen "%s"',
    'Add a new project restriction' => 'Ny prosjektrestriksjon',
    'Add a new drag and drop restriction' => 'Ny dra og slipp-restriksjon',
    'Add a new column restriction' => 'Ny kolonnerestriksjon',
    'Edit this role' => 'Rediger rolle',
    'Remove this role' => 'Fjern denne rollen',
    'There is no restriction for this role.' => 'Denne rollen har ingen restriksjoner',
    'Only moving task between those columns is permitted' => 'Oppgaver kan kun flyttes mellom disse kolonnene',
    'Close a task in a specific column when not moved during a given period' => 'Lukk oppgave i angitt kolonne når den ikke flyttes i en angitt periode',
    'Edit columns' => 'Endre kolonner',
    'The column restriction has been created successfully.' => 'Kolonnerestriksjonen er opprettet',
    'Unable to create this column restriction.' => 'Kunne ikke opprette denne kolonnerestriksjonen',
    'Column restriction removed successfully.' => 'Kolonnerestriksjon fjernet',
    'Unable to remove this restriction.' => 'Kan ikke fjerne denne restriksjonen',
    'Your custom project role has been created successfully.' => 'Egendefinert prosjektrolle er oppdatert',
    'Unable to create custom project role.' => 'Kunne ikke opprette egendefinert prosjektrolle',
    'Your custom project role has been updated successfully.' => 'Egendefinert ptosjektrolle er endret',
    'Unable to update custom project role.' => 'Kunne ikke endre egendefinert prosjektrolle',
    'Custom project role removed successfully.' => 'Egendefinert prosjektrolle er fjernet',
    'Unable to remove this project role.' => 'Kunne ikke fjerne denne prosjektrollen',
    'The project restriction has been created successfully.' => 'Prosjektrestriksjonen er opprettet',
    'Unable to create this project restriction.' => 'Kunne ikke opprette prosjektrestriksjon',
    'Project restriction removed successfully.' => 'Prosjektrestriksjon er fjernet',
    'You cannot create tasks in this column.' => 'Du kan ikke opprette oppgaver i denne kolonnen',
    'Task creation is permitted for this column' => 'Oppretting av oppgaver er tillatt i denne kolonnen',
    'Closing or opening a task is permitted for this column' => 'Lukking/åpning av oppgaver er tillatt i denne kolonnen',
    'Task creation is blocked for this column' => 'Denne kolonnen er låst for oppretting av nye oppgaver',
    'Closing or opening a task is blocked for this column' => 'Oppgaver i denne kolonnen er låst for lukking/åpning',
    'Task creation is not permitted' => 'Kan ikke opprette oppgaver',
    'Closing or opening a task is not permitted' => 'Kan ikke lukke eller åpne oppgaver',
    'New drag and drop restriction for the role "%s"' => 'Ny dra-og-slipp-restriksjon for rollen "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Brukere med denne rollen vil bare kunne flytte oppgaver mellom kilde- og målkolonne.',
    'Remove a column restriction' => 'Fjern kolonnerestriksjon',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Ønsker du virkelig å fjerne kolonnerestriksjonen: "%s" til "%s"?',
    'New column restriction for the role "%s"' => 'Ny kolonnerestriksjon for rollen "%s"',
    'Rule' => 'Regel',
    'Do you really want to remove this column restriction?' => 'Er du sikker på at du vil fjerne denne kolonnerestriksjonen',
    'Custom roles' => 'Egendefinerte roller',
    'New custom project role' => 'Ny egendefinert rolle',
    'Edit custom project role' => 'Endre egendefinert rolle',
    'Remove a custom role' => 'Fjern egendefinert rolle',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Ønsker du virkelig å fjerne den egendefinerte rollen: "%s"? Alle brukere med denne rollen vil bli prosjektmedlemmer.',
    'There is no custom role for this project.' => 'Prosjektet har ingen egendefinerte roller',
    'New project restriction for the role "%s"' => 'Ny prosjektrestriksjon for rollen "%s"',
    'Restriction' => 'Restriksjon',
    'Remove a project restriction' => 'Fjern prosjektrestriksjon',
    'Do you really want to remove this project restriction: "%s"?' => 'Er du sikker på at du vil fjerne restriksjonen "%s"',
    'Duplicate to multiple projects' => 'Dupliser til flere prosjekter',
    'This field is required' => 'Feltet er påkrevet',
    'Moving a task is not permitted' => 'Flytting av oppgaven er ikke tillatt',
    'This value must be in the range %d to %d' => 'Verdien må være i området %d to %d',
    'You are not allowed to move this task.' => 'Du har ikke rettigheter til å flutte denne oppgaven',
    'API User Access' => 'API brukertilgang',
    'Preview' => 'Forhåndsvisning',
    'Write' => 'Skriv',
    'Write your text in Markdown' => 'Du kan skrive teksten din i Markdown hvis du ønsker det.',
    'No personal API access token registered.' => 'Ingen personlig API tilgangsnøkkel er registrert.',
    'Your personal API access token is "%s"' => 'Din personlige API tilgangsnøkkel er "%s"',
    'Remove your token' => 'Fjern din nøkkel',
    'Generate a new token' => 'Lag ny nøkkel',
    'Showing %d-%d of %d' => 'Viser %d-%d of %d',
    'Outgoing Emails' => 'Utgående e-post',
    'Add or change currency rate' => 'Legg til eller endre valuta',
    'Reference currency: %s' => 'Referansevaluta: %s',
    'Add custom filters' => 'Lag egendefinerte filtere',
    'Export' => 'Eksporter',
    'Add link label' => 'Ny etikett',
    'Incompatible Plugins' => 'Ukompatible innstikk',
    'Compatibility' => 'Kompatibilitet',
    'Permissions and ownership' => 'Tillatelser og eierskap',
    'Priorities' => 'Prioriteter',
    'Close this window' => 'Lukk vindu',
    'Unable to upload this file.' => 'Kunne ikke laste opp filen',
    'Import tasks' => 'Importere oppgaver',
    'Choose a project' => 'Velg prosjekt',
    'Profile' => 'Profil',
    'Application role' => 'Rolle',
    '%d invitations were sent.' => '%d invitasjoner ble sendt',
    '%d invitation was sent.' => '%d invitasjon ble sendt',
    'Unable to create this user.' => 'Kan ikke opprette brukeren.',
    'Kanboard Invitation' => 'Kanboard invitasjon',
    'Visible on dashboard' => 'Synlig på dashbordet',
    'Created at:' => 'Opprettet:',
    'Updated at:' => 'Endret:',
    'There is no custom filter.' => 'Ingen egendefinerte filtre',
    'New User' => 'Ny bruker',
    'Authentication' => 'Autentisering',
    'If checked, this user will use a third-party system for authentication.' => 'Dersom dette er valgt vil brukeren logges inn via et tredjepartssystem',
    'The password is necessary only for local users.' => 'Passord er kun nødvendig for lokale brukere',
    'You have been invited to register on Kanboard.' => 'Du er invitert til å registrere deg på Kanboard',
    'Click here to join your team' => 'Klikk her for å bli med i teamet ditt',
    'Invite people' => 'Inviter personer',
    'Emails' => 'E-poster',
    'Enter one email address by line.' => 'Legg inn en e-postadresse pr. linje',
    'Add these people to this project' => 'Legg til disse personene i prosjektet',
    'Add this person to this project' => 'Legg til denne personen i prosjektet',
    'Sign-up' => 'Registrering',
    'Credentials' => 'Akkreditiver',
    'New user' => 'Ny bruker',
    'This username is already taken' => 'Brukernavn finnes fra før',
    'Your profile must have a valid email address.' => 'Brukerprofilen din må ha en gyldig e-postadresse.',
    'TRL - Turkish Lira' => 'TRL - Tyrkiske lira',
    'The project email is optional and could be used by several plugins.' => 'Du kan angi en e-postadresse for prosjektet, og den kan brukes av ulike innstikksmoduler',
    'The project email must be unique across all projects' => 'Prosjektets e-postadresse må være unik for alle prosjekter',
    'The email configuration has been disabled by the administrator.' => 'Administrator har deaktivert e-postinnstillinger',
    'Close this project' => 'Lukk dette prosjektet',
    'Open this project' => 'Gjenåpne dette prosjektet',
    'Close a project' => 'Lukk et prosekt',
    'Do you really want to close this project: "%s"?' => 'Er du sikker på at vil lukke prosjektet: "%s"?',
    'Reopen a project' => 'Gjenåpne prosjekt',
    'Do you really want to reopen this project: "%s"?' => 'Er du sikker på at du vil gjenåpne prosjektet: "%s"?',
    'This project is open' => 'Dette prosjektet er aktivt',
    'This project is closed' => 'Dette prosjektet er lukket',
    'Unable to upload files, check the permissions of your data folder.' => 'Kunne ikke laste opp filen!',
    'Another category with the same name exists in this project' => 'Kategorien finnes allerede i dette prosjektet',
    'Comment sent by email successfully.' => 'Kommentar sendt med e-post.',
    'Sent by email to "%s" (%s)' => 'Sendt med e-post til "%s" (%s)',
    'Unable to read uploaded file.' => 'Kan ikke lese opplastet fil.',
    'Database uploaded successfully.' => 'Databasen er lastet opp.',
    'Task sent by email successfully.' => 'Oppgaven er sendt med e-post.',
    'There is no category in this project.' => 'Prosjektet har ingen kategorier.',
    'Send by email' => 'Send i e-post',
    'Create and send a comment by email' => 'Opprett og send en kommentar med e-post',
    'Subject' => 'Emne',
    'Upload the database' => 'Last opp databasen',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Du kan laste opp en tidligere nedlastet Sqlite database (Gzip-format).',
    'Database file' => 'Databasefil',
    'Upload' => 'Last opp',
    'Your project must have at least one active swimlane.' => 'Prosjektet må ha minst en aktiv svømmebane',
    'Project: %s' => 'Prosjekt: %s',
    'Automatic action not found: "%s"' => 'Finner ingen automatisk handling: "%s"',
    '%d projects' => '%d prosjekter',
    '%d project' => '%d prosjekt',
    'There is no project.' => 'Ingen prosjekter',
    'Sort' => 'Sorter',
    'Project ID' => 'Prosjekt-ID',
    'Project name' => 'Prosjektnavn',
    'Public' => 'Felles',
    'Personal' => 'Privat',
    '%d tasks' => '%d oppgaver',
    '%d task' => '%d oppgave',
    'Task ID' => 'Oppgave-ID',
    'Assign automatically a color when due date is expired' => 'Tilordne farge automatisk når fristen utløper',
    'Total score in this column across all swimlanes' => 'Totalt resultat for denne kolonnen i alle svømmebaner',
    'HRK - Kuna' => 'HRK - Kroatiske kuna',
    'ARS - Argentine Peso' => 'ARS - Argentinske pesos',
    'COP - Colombian Peso' => 'COP - Columbianske pesos',
    '%d groups' => '%d grupper',
    '%d group' => '%d gruppe',
    'Group ID' => 'Gruppe-ID',
    'External ID' => 'Ekstern ID',
    '%d users' => '%d brukere',
    '%d user' => '%d bruker',
    'Hide subtasks' => 'Skjul deloppgaver',
    'Show subtasks' => 'Vis deloppgaver',
    'Authentication Parameters' => 'Autensitering',
    'API Access' => 'API-tilgang',
    'No users found.' => 'Finner ingen brukere',
    'User ID' => 'Bruker-ID',
    'Notifications are activated' => 'Varslinger aktivert',
    'Notifications are disabled' => 'Varslinger deaktivert',
    'User disabled' => 'Bruker er deaktivert',
    '%d notifications' => '%d varslinger',
    '%d notification' => '%d varsling',
    'There is no external integration installed.' => 'Ingen ekstern interasjon er installert.',
    'You are not allowed to update tasks assigned to someone else.' => 'Du kan ikke endre oppgaver hvor en annen bruker er ansvarlig',
    'You are not allowed to change the assignee.' => 'Du har ikke rettigheter til å endre ansvarlig',
    'Task suppression is not permitted' => 'Endring av posisjon er ikke tillatt',
    'Changing assignee is not permitted' => 'Endring av ansvarlig er ikke tillatt',
    'Update only assigned tasks is permitted' => 'Du kan bare endre oppgaver du selv er ansvarlig for',
    'Only for tasks assigned to the current user' => 'Kun for oppgaver tilordnet aktiv bruker',
    'My projects' => 'Mine prosjekter',
    'You are not a member of any project.' => 'Du er ikke med i noen prosjekter',
    'My subtasks' => 'Mine deloppgaver',
    '%d subtasks' => '%d deloppgaver',
    '%d subtask' => '%d deloppgave',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Aktiv bruker kan kun flytte oppgaver mellom angitte kolonner',
    '[DUPLICATE]' => 'DUPLISER',
    'DKK - Danish Krona' => 'DKK - Danske kroner',
    'Remove user from group' => 'Fjern bruker fra gruppen',
    'Assign the task to its creator' => 'Tildel oppgaven til den som har opprettet den',
    'This task was sent by email to "%s" with subject "%s".' => 'Denne oppgaven ble sendt på e-post til "%s" med emne "%s".',
    'Predefined Email Subjects' => 'Forhåndsdefinerte e-post emner',
    'Write one subject by line.' => 'Skriv et emne på hver linje',
    'Create another link' => 'Lag en ny lenke',
    'BRL - Brazilian Real' => 'BRL - Brasilianske real',
    'Add a new Kanboard task' => 'Lag ny oppgave',
    'Subtask not started' => 'Deloppgaven er ikke startet',
    'Subtask currently in progress' => 'Deloppgaver i prosess',
    'Subtask completed' => 'Deloppgave fullført',
    'Subtask added successfully.' => 'Deloppgave er lagt til',
    '%d subtasks added successfully.' => '%d deloppgaver er lagt til',
    'Enter one subtask by line.' => 'Legg inn en deloppgave pr. rad',
    'Predefined Contents' => 'Forhåndsdefinert innhold',
    'Predefined contents' => 'Forhåndsdefinert innhold',
    'Predefined Task Description' => 'Forhåndsdefinert oppgavebeskrivelse',
    'Do you really want to remove this template? "%s"' => 'Ønsker du virkelig å slette denne malen? "%s"',
    'Add predefined task description' => 'Ny forhåndsdefinert oppgavebeskrivelse',
    'Predefined Task Descriptions' => 'Forhåndsdefinerte oppgavebeskrivelser',
    'Template created successfully.' => 'Malen er opprettet',
    'Unable to create this template.' => 'Kunne ikke opprette malen',
    'Template updated successfully.' => 'Malen er endret',
    'Unable to update this template.' => 'Kunne ikke endre malen',
    'Template removed successfully.' => 'Malen er slettet',
    'Unable to remove this template.' => 'Kunne ikke slette malen',
    'Template for the task description' => 'Mal for oppgavbeskrivelse',
    'The start date is greater than the end date' => 'Startdato er større en sluttdato',
    'Tags must be separated by a comma' => 'Etiketter må skilles med komma',
    'Only the task title is required' => 'Kun oppgavetittel er påkrevet',
    'Creator Username' => 'Opprettet av',
    'Color Name' => 'Farge',
    'Column Name' => 'Kolonne',
    'Swimlane Name' => 'Svømmebane',
    'Time Estimated' => 'Estimert tid',
    'Time Spent' => 'Medgått tid',
    'External Link' => 'Ekstern lenke',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'OBS Forsiktig: Denne funksjonen aktiverer iCal-strøm, RSS-strøm og offentlig tavlevisning!',
    'Stop the timer of all subtasks when moving a task to another column' => 'Stopp timeren for alle deloppgaver når en oppgave flyttes til en annen kolonne',
    'Subtask Title' => 'Deloppgave',
    'Add a subtask and activate the timer when moving a task to another column' => 'Opprett en deloppgave og aktiver timeren når en oppgave flyttes til en annen kolonne',
    'days' => 'dager',
    'minutes' => 'minutter',
    'seconds' => 'sekunder',
    'Assign automatically a color when preset start date is reached' => 'Tilordne farge automatisk på valgt startdato',
    'Move the task to another column once a predefined start date is reached' => 'Flytt oppgaven til en annen lolonne på valgt startdato',
    'This task is now linked to the task %s with the relation "%s"' => 'Oppgaven er nå lenket til oppgaven %s med relasjonen "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Lenken med relasjonen "%s" til oppgaven %s er fjernet',
    'Custom Filter:' => 'Egendefinert filter',
    'Unable to find this group.' => 'Finner ikke gruppen',
    '%s moved the task #%d to the column "%s"' => '%s flyttet oppgaven #%d til kolonnen "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s flyttet oppgaven #%d til posisjon %d i kolonnen "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s flyttet oppgaven #%d til svømmebane "%s"',
    '%sh spent' => '%st brukt',
    '%sh estimated' => '%st estimert',
    'Select All' => 'Velg alle',
    'Unselect All' => 'Fravelg alle',
    'Apply action' => 'Utfør',
    'Move selected tasks to another column or swimlane' => 'Flytt merkede oppgaver til en annen kolonne',
    'Edit tasks in bulk' => 'Masseredigering av oppgaver',
    'Choose the properties that you would like to change for the selected tasks.' => 'Velg egenskapene du vil endre for valgte oppgaver.',
    'Configure this project' => 'Prosjekt',
    'Start now' => 'Start nå',
    '%s removed a file from the task #%d' => '%s fjernet en fil fra oppgaven #%d',
    'Attachment removed from task #%d: %s' => 'Vedlegg fjernet fra oppgave #%d: %s',
    'No color' => 'Ingen farge',
    'Attachment removed "%s"' => 'Vedlegg fjernet "%s"',
    '%s removed a file from the task %s' => '%s fjernet en fil fra oppgaven %s',
    'Move the task to another swimlane when assigned to a user' => 'Flytt oppgaven til en annen svømmebane når den tildeles en bruker',
    'Destination swimlane' => 'Mål-svømmebane',
    'Assign a category when the task is moved to a specific swimlane' => 'Tildel en kategori når oppgaven flyttes til en bestemt svømmebane',
    'Move the task to another swimlane when the category is changed' => 'Flytt oppgaven til en annen svømmebane når kategorien endres',
    'Reorder this column by priority (ASC)' => 'Sorter denne kolonnen etter prioritet (stigende)',
    'Reorder this column by priority (DESC)' => 'Sorter denne kolonnen etter prioritet (synkende)',
    'Reorder this column by assignee and priority (ASC)' => 'Sorter denne kolonnen etter ansvarlig og prioritet (stigende)',
    'Reorder this column by assignee and priority (DESC)' => 'Sorter denne kolonnen etter ansvarlig og prioritet (synkende)',
    'Reorder this column by assignee (A-Z)' => 'Sorter denne kolonnen etter ansvarlig (A–Å)',
    'Reorder this column by assignee (Z-A)' => 'Sorter denne kolonnen etter ansvarlig (Å–A)',
    'Reorder this column by due date (ASC)' => 'Sorter denne kolonnen etter forfallsdato (stigende)',
    'Reorder this column by due date (DESC)' => 'Sorter denne kolonnen etter forfallsdato (synkende)',
    'Reorder this column by id (ASC)' => 'Sorter denne kolonnen etter ID (stigende)',
    'Reorder this column by id (DESC)' => 'Sorter denne kolonnen etter ID (synkende)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s flyttet oppgaven #%d "%s" til prosjektet "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Oppgave #%d "%s" har blitt flyttet til prosjektet "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Flytt oppgaven til en annen kolonne når forfallsdatoen er mindre enn et bestemt antall dager',
    'Automatically update the start date when the task is moved away from a specific column' => 'Oppdater startdatoen automatisk når oppgaven flyttes fra en bestemt kolonne',
    'HTTP Client:' => 'HTTP-klient:',
    'Assigned' => 'Tildelt',
    'Task limits apply to each swimlane individually' => 'Oppgavegrenser gjelder for hver svømmebane individuelt',
    'Column task limits apply to each swimlane individually' => 'Kolonneoppgavegrenser gjelder for hver svømmebane individuelt',
    'Column task limits are applied to each swimlane individually' => 'Kolonneoppgavegrenser brukes på hver svømmebane individuelt',
    'Column task limits are applied across swimlanes' => 'Kolonneoppgavegrenser brukes på tvers av svømmebaner',
    'Task limit: ' => 'Oppgavegrense: ',
    'Change to global tag' => 'Endre til global tag',
    'Do you really want to make the tag "%s" global?' => 'Vil du virkelig gjøre taggen "%s" global?',
    'Enable global tags for this project' => 'Aktiver globale tagger for dette prosjektet',
    'Group membership(s):' => 'Gruppemedlemskap:',
    '%s is a member of the following group(s): %s' => '%s er medlem av følgende gruppe(r): %s',
    '%d/%d group(s) shown' => '%d/%d gruppe(r) vist',
    'Subtask creation or modification' => 'Opprettelse eller endring av deloppgave',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Tildel oppgaven til en bestemt bruker når den flyttes til en bestemt svømmebane',
    'Comment' => 'Kommentar',
    'Collapse vertically' => 'Skjul vertikalt',
    'Expand vertically' => 'Utvid vertikalt',
    'MXN - Mexican Peso' => 'MXN - Meksikansk peso',
    'Estimated vs actual time per column' => 'Estimert vs faktisk tid per kolonne',
    'HUF - Hungarian Forint' => 'HUF - Ungarsk forint',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Du må velge en fil for å laste opp som din avatar!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Filen du lastet opp er ikke et gyldig bilde! (Kun *.gif, *.jpg, *.jpeg og *.png er tillatt!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Angi forfallsdato automatisk når oppgaven flyttes fra en bestemt kolonne',
    'No other projects found.' => 'Ingen andre prosjekter funnet.',
    'Tasks copied successfully.' => 'Oppgaver kopiert vellykket.',
    'Unable to copy tasks.' => 'Kan ikke kopiere oppgaver.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Lyst tema',
    'Dark theme' => 'Mørkt tema',
    'Automatic theme - Sync with system' => 'Automatisk tema - Synkroniser med systemet',
    'Application managers or more' => 'Applikasjonsadministratorer eller høyere',
    'Administrators' => 'Administratorer',
    'Visibility:' => 'Synlighet:',
    'Standard users' => 'Standardbrukere',
    'Visibility is required' => 'Synlighet er påkrevd',
    'The visibility should be an app role' => 'Synligheten bør være en applikasjonsrolle',
    'Reply' => 'Svar',
    '%s wrote: ' => '%s skrev: ',
    'Number of visible tasks in this column and swimlane' => 'Antall synlige oppgaver i denne kolonnen og svømmebanen',
    'Number of tasks in this swimlane' => 'Antall oppgaver i denne svømmebanen',
    'Unable to find another subtask in progress, you can close this window.' => 'Kan ikke finne en annen deloppgave i arbeid, du kan lukke dette vinduet.',
    'This theme is invalid' => 'Dette temaet er ugyldig',
    'This role is invalid' => 'Denne rollen er ugyldig',
    'This timezone is invalid' => 'Denne tidssonen er ugyldig',
    'This language is invalid' => 'Dette språket er ugyldig',
    'This URL is invalid' => 'Denne URL-en er ugyldig',
    'Date format invalid' => 'Ugyldig datoformat',
    'Time format invalid' => 'Ugyldig tidsformat',
    'Invalid Mail transport' => 'Ugyldig e-posttransport',
    'Color invalid' => 'Ugyldig farge',
    'This value must be greater or equal to %d' => 'Denne verdien må være større enn eller lik %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Legg til en BOM i begynnelsen av filen (påkrevd for Microsoft Excel)',
    'Just add these tag(s)' => 'Bare legg til disse taggene',
    'Remove internal link(s)' => 'Fjern interne lenker',
    'Import tasks from another project' => 'Importer oppgaver fra et annet prosjekt',
    'Select the project to copy tasks from' => 'Velg prosjektet du vil kopiere oppgaver fra',
    'The total maximum allowed attachments size is %sB.' => 'Den totale maksimalt tillatte vedleggsstørrelsen er %sB.',
    'Add attachments' => 'Legg til vedlegg',
    'Task #%d "%s" is overdue' => 'Oppgaven #%d "%s" er forsinket',
    'Enable notifications by default for all new users' => 'Aktiver varslinger som standard for alle nye brukere',
];
